#
# spec file for package liblxqt
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           liblxqt
Version:        0.11.0
Release:        2.2
Summary:        Core utility library for LXQt
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.lxqt.org
Source:         http://downloads.lxqt.org/lxqt/%{version}/%{name}-%{version}.tar.xz
Source1:        http://downloads.lxqt.org/lxqt/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.0.2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xdg) >= 1.3.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xscrnsaver)
Obsoletes:      liblxqt-qt5 < %{version}
Provides:       liblxqt-qt5 = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
liblxqt represents the core library of LXQt providing essential
functionality needed by nearly all of its components.

%package -n liblxqt0
Summary:        LXQt core library
Group:          System/Libraries
Recommends:     %{name}-lang

%description -n liblxqt0
liblxqt represents the core library of LXQt providing essential
functionality needed by nearly all of its components.

%package devel
Summary:        Devel files for liblxqt
Group:          Development/Libraries/C and C++
Requires:       liblxqt0 = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(Qt5Xdg)

%description devel
liblxqt represents the core library of LXQt providing essential
functionality needed by nearly all of its components.

This subpackage contains libraries and header files for developing
applications that want to make use of liblxqt.

%prep
%setup -q -n liblxqt-%{version}

%build
%cmake -DPULL_TRANSLATIONS=No
make %{?_smp_mflags}

%install
%cmake_install

%post -n liblxqt0 -p /sbin/ldconfig

%postun -n liblxqt0 -p /sbin/ldconfig

%files -n liblxqt0
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_libdir}/%{name}.so.0
%{_libdir}/%{name}.so.0.*

%files devel
%defattr (-,root,root)
%{_includedir}/lxqt/
%{_datadir}/cmake/
%{_libdir}/pkgconfig/lxqt.pc
%{_libdir}/%{name}.so

%changelog
* Fri Sep 30 2016 jengelh@inai.de
- Update descriptions. Drop seemingly unneeded Provides: liblxqt.
  Own all directories.
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Bump version ot 0.11.0 (#105)
  * Settings: Make use of reverse_iterator conditional
  * Application: Add <cerrno> include
  * Settings: Add "homemade" XDG_CONFIG_DIRS support
  * Settings: unify duplicated code
  * Add README.md
  * translations: Change default translations repository
  * Update DBus Notify method annotation name
  * Fix lupdate warning missing Q_OBJECT macro
  * Replaces deprecated QStyleOptionViewItemV4
  * Don't lock the screen when it's already locked.
  * lxqtscreensaver: Makes it a opaque pointer class
  * GridLayout: Store current animation flag
  * lxqtgridlayout: Move private class definition
  * HtmlDelegate: Take layoutDirection into account
  * GridLayout: Take layoutDirection into account
  * application: Correct signal handling & clean-up (#72)
  * lxqtpower: Removes unused stuff
  * SingleApplication: Only create an DBus adaptor when needed
  * NotificationPrivate: Fixes programming typo
  * Don't set icon theme name
  * configdialog: Update icons in ThemeChanged event
  * lxqtpower: Add suspend and hibernate to ConsoleKit2 provider
  * LXQtTranslateTs.cmake: Enable PULL_TRANSLATIONS by default
  * LXQtTranslateTs.cmake: Use/update template in remote repo
  * .gitignore: Cleanup
  * build: Use external translations
  * ts-files removal (#90)
  * GridLayout: Fix memory leak
  * translations: Fix external translations logic
  * translations: Add external translations support
  * configdialog: Fix icon bar sizing
  * configdialog: fix size of PageSelectWidget (#83)
  * Use const references with the foreach iterator
  * SettingsCache: Improve performance
  * Print warning messages when using the fallback Icon Theme
  * Use LXQT_DATA_DIR for fallback icon theme search path
  * Sets Oxygen as the only fallback icon theme
  * Adds CMAKE_INSTALL_PREFIX to the LXQt Theme search paths
  * LXQtCompilerSettings: Add QT_USE_QSTRINGBUILDER to the compile definitions
  * SingleApplication: Use QCoreApplication::exit() instead of ::exit()
  * bump year
  * TranslateDesktopTs: Adds UPDATE_OPTIONS options
  * TranslateDesktop: Remove lupdate absolute option
  * TranslateDesktop: Use -a switch in grep commands
  * LXQtTheme: Remove (outdated) "singleclick" qss assembly
  * settings: Upgrade emitting of "changed" signals
  * SingleApplication: Call also QWidget::show on activate
  * Updated Russian translation Removed ru_RU file
  * Use QString() instead of ""
  * Use CMAKE_INSTALL_FULL_DATAROOTDIR
  * Add LXQT_GRAPHICS_DIR directory definition
  * lxqt-config: Correct escaping while setting variables
  * CMake: Removes artifact
  * Adds FindXdgUserDirs CMake find_package module
  * Italian translation update
* Tue Nov 10 2015 mvetter@suse.com
- Remove patch 0001-fix-build-with-qt-5.5.patch
  Contained in upstream version
* Thu Nov  5 2015 mvetter@suse.com
- Upstream release 0.10.0
* Thu Oct  8 2015 mvetter@suse.com
- Factory moved fom libqt5.4 to 5.5
  0001-fix-build-with-qt-5.5.patch: include QObject header explicitly
* Thu Jul  9 2015 mvetter@suse.com
- Use correct name "lxqt" instead of "lxde-qt"
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed to %%cmake and %%cmake_install macros in %%build and
  %%install
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Dropped -qt5 package naming, as none of the internal library
  names use -qt5 in 0.9.0.  Added Obsoletes and Conflicts, in the
  odd chance that liblxqt-0.7.0 and liblxqt >=0.8.0 are installed
  on the same system.  Which should never happen.  lxqt-0.9.0 is not
  likely to be pushed to 13.2, and liblxqt can no longer be built
  against Qt4.
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals to build for Fedora
* Fri Oct 24 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- spec file clean up
* Tue May 13 2014 sfalken@opensuse.org
- Cleaned up BuildRequires:
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora spec, split into seperate subproject
  Del: liblxqt-Fedora_20.spec
* Sun May 11 2014 sfalken@opensuse.org
- Removed BuildRequires: pkgconfig entries in favour of BuildRequires: libqt4-devel at request of X11:lxde:lxqt maintainers
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add: liblxqt-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add: liblxqt-0.7.0.tar.xz
  Del: _service
* Thu Apr 17 2014 sfalken@opensuse.org
- Shortened Summary: to make rpmlint happy
  Removed explicit Requires: per rpmlint
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed direct calls to cmake, in favour of %%cmake and %%cmake_install macros
* Wed Apr  2 2014 sfalken@opensuse.org
- Specfile finalized
* Wed Apr  2 2014 sfalken@opensuse.org
- Inital Source Upload
  Add:  _service
  Add:  liblxqt.spec
  Add:  liblxqt.changes
